@@ -1,8 +1,8 @@
-/* $NetBSD: ecma167-udf.h,v 1.5 2006/10/22 00:06:48 reinoud Exp $ */
+/* $NetBSD: ecma167-udf.h,v 1.14 2011/07/07 17:45:38 reinoud Exp $ */
 
 /*-
- * Copyright (c) 2003, 2004, 2005, 2006, 2011
- * 	Reinoud Zandijk <reinoud@netbsd.org>
+ * Copyright (c) 2003, 2004, 2005, 2006, 2008, 2009, 2017, 2018
+ * 	Reinoud Zandijk <reinoud@NetBSD.org>
  * Copyright (c) 2001, 2002 Scott Long <scottl@freebsd.org>
  * All rights reserved.
  *
@@ -29,9 +29,9 @@
  *
  * 
  * Extended and adapted for UDFv2.50+ bij Reinoud Zandijk based on the
- * origional by Scott Long.
+ * original by Scott Long.
  * 
- * 20030508 Made some small typo and explainatory comments
+ * 20030508 Made some small typo and explanatory comments
  * 20030510 Added UDF 2.01 structures
  * 20030519 Added/correct comments on multi-partitioned logical volume space
  * 20050616 Added pseudo overwrite
@@ -59,11 +59,9 @@
  * after the closing brace.
 */
 
-#if 1
 #ifndef __packed
 #define __packed __attribute__((packed))
 #endif
-#endif
 
 
 /* ecma167-udf.h */
@@ -104,13 +102,13 @@ enum {
 	TAGID_FSD =		256,
 	TAGID_FID =		257,
 	TAGID_ALLOCEXTENT = 	258,
-	TAGID_INDIRECT_ENTRY =	259,
+	TAGID_INDIRECTENTRY =	259,
 	TAGID_ICB_TERM =	260,
 	TAGID_FENTRY =		261,
 	TAGID_EXTATTR_HDR =	262,
 	TAGID_UNALL_SP_ENTRY =	263,
 	TAGID_SPACE_BITMAP = 	264,
-	TAGID_PART_INTEGRETY = 	265,
+	TAGID_PART_INTEGRITY = 	265,
 	TAGID_EXTFENTRY =	266,
 	TAGID_MAX =		266
 };
@@ -124,11 +122,11 @@ enum {
 
 enum {
 	UDF_ACCESSTYPE_NOT_SPECIFIED   = 0,	/* unknown				*/
-	UDF_ACCESSTYPE_PSEUDO_OVERWITE = 0,	/* Pseudo overwritable, f.e. BD-R's LOW */
+	UDF_ACCESSTYPE_PSEUDO_OVERWITE = 0,	/* pseudo overwritable, e.g. BD-R's LOW */
 	UDF_ACCESSTYPE_READ_ONLY       = 1,	/* really only readable			*/
 	UDF_ACCESSTYPE_WRITE_ONCE      = 2,	/* write once and you're done		*/
 	UDF_ACCESSTYPE_REWRITEABLE     = 3,	/* may need extra work to rewrite	*/
-	UDF_ACCESSTYPE_OVERWRITABLE    = 4	/* no limits on rewriting; harddisc f.e.*/
+	UDF_ACCESSTYPE_OVERWRITABLE    = 4	/* no limits on rewriting; e.g. harddisc*/
 };
 
 
@@ -205,13 +203,14 @@ union icb {
 
 
 /* short/long/ext extent have flags encoded in length */
-#define UDF_EXT_ALLOCATED              (0<<30)
-#define UDF_EXT_FREED                  (1<<30)
-#define UDF_EXT_ALLOCATED_BUT_NOT_USED (1<<30)
-#define UDF_EXT_FREE                   (2<<30)
-#define UDF_EXT_REDIRECT               (3<<30)
-#define UDF_EXT_FLAGS(len) ((len) & (3<<30))
-#define UDF_EXT_LEN(len)   ((len) & ((1<<30)-1))
+#define UDF_EXT_ALLOCATED              (0U<<30)
+#define UDF_EXT_FREED                  (1U<<30)
+#define UDF_EXT_ALLOCATED_BUT_NOT_USED (1U<<30)
+#define UDF_EXT_FREE                   (2U<<30)
+#define UDF_EXT_REDIRECT               (3U<<30)
+#define UDF_EXT_FLAGS(len) ((len) & (3U<<30))
+#define UDF_EXT_LEN(len)   ((len) & ((1U<<30)-1))
+#define UDF_EXT_MAXLEN     ((1U<<30)-1)
 
 
 /* Character set spec [1/7.2.1] */
@@ -266,9 +265,9 @@ struct icb_tag {
 	uint32_t	prev_num_dirs;
 	uint16_t	strat_type;
 	union {
-		uint8_t		strat_param[2];
-		uint16_t	strat_param16;
-	} __packed;
+		uint8_t	 strat_param[2];
+		uint16_t strat_param16;
+	};
 	uint16_t	max_num_entries;
 	uint8_t		reserved;
 	uint8_t		file_type;
@@ -331,7 +330,7 @@ struct vol_desc_ptr {
 struct pri_vol_desc {
 	struct desc_tag		tag;
 	uint32_t		seq_num;		/* MAX prevail */
-	uint32_t		pvd_num;		/* assigned by author; 0 is special as in it may only occure once */
+	uint32_t		pvd_num;		/* assigned by author; 0 is special as in it may only occur once */
 	char			vol_id[32];		/* KEY ; main identifier of this disc */
 	uint16_t		vds_num;		/* volume descriptor number; i.e. what volume number is it */
 	uint16_t		max_vol_seq;		/* maximum volume descriptor number known */
@@ -349,7 +348,7 @@ struct pri_vol_desc {
 	struct regid		imp_id;
 	uint8_t			imp_use[64];
 	uint32_t		prev_vds_loc;		/* location of predecessor _lov ? */
-	uint16_t		flags;			/* bit 0 : if set indicates volume set name is meaningfull */
+	uint16_t		flags;			/* bit 0 : if set indicates volume set name is meaningful */
 	uint8_t			reserved[22];
 } __packed;
 
@@ -376,7 +375,7 @@ struct impvol_desc {
 	union {
 		struct udf_lv_info	lv_info;
 		char			impl_use[460];
-	}_impl_use;
+	} _impl_use;
 } __packed;
 
 
@@ -468,7 +467,7 @@ struct part_map_meta {
 	uint32_t		meta_mirror_file_lbn;
 	uint32_t		meta_bitmap_file_lbn;
 	uint32_t		alloc_unit_size;	/* allocation unit size in blocks */
-	uint16_t		alignment_unit_size;	/* alignment nessisary in blocks  */
+	uint16_t		alignment_unit_size;	/* alignment necessary in blocks  */
 	uint8_t			flags;
 	uint8_t			reserved1[5];
 } __packed;
@@ -487,8 +486,8 @@ union udf_pmap {
 
 /* Sparing Map Entry [UDF 2.01/2.2.11] */
 struct spare_map_entry {
-	uint32_t		org;			/* partion relative address  */
-	uint32_t		map;			/* absolute disc address (!) can be in partion, but doesn't have to be */
+	uint32_t		org;			/* partition relative address  */
+	uint32_t		map;			/* absolute disc address (!) can be in partition, but doesn't have to be */
 } __packed;
 
 
@@ -568,7 +567,7 @@ struct part_desc {
 		uint8_t			contents_use[128];
 	} _impl_use;
 	uint32_t		access_type;		/* R/W, WORM etc. */
-	uint32_t		start_loc;		/* start of partion with given length */
+	uint32_t		start_loc;		/* start of partition with given length */
 	uint32_t		part_len;
 	struct regid		imp_id;
 	uint8_t			imp_use[128];
@@ -687,9 +686,9 @@ struct impl_extattr_entry {
 	uint32_t		iu_l;
 	struct regid		imp_id;
 	union {
-		uint8_t			data[1];
-		uint16_t		data16;
-	} __packed;
+		uint8_t	 data[1];
+		uint16_t data16;
+	};
 } __packed;
 
 
@@ -707,7 +706,7 @@ struct filetimes_extattr_entry {
 	struct extattr_entry    hdr;
 	uint32_t		d_l;		/* length of times[] data following */
 	uint32_t		existence;	/* bitmask */
-	struct timestamp	times[1];	/* in order of assending bits */
+	struct timestamp	times[1];	/* in order of ascending bits */
 } __packed;
 #define UDF_FILETIMES_ATTR_NO	5
 #define UDF_FILETIMES_FILE_CREATION	1
@@ -838,13 +837,4 @@ union dscrptr {
 };
 
 
-/* Useful defines */
-
-#define	GETICB(ad_type, fentry, offset)	\
-	(struct ad_type *)&fentry->data[offset]
-
-#define	GETICBLEN(ad_type, icb)	((struct ad_type *)(icb))->len
-
-
 #endif /* !_FS_UDF_ECMA167_UDF_H_ */
-
