@@ -2,7 +2,7 @@
 
 /*
  * File "udf_unix.c" is part of the UDFclient toolkit.
- * File $Id: udf_unix.c,v 1.17 2016/04/25 21:01:40 reinoud Exp $
+ * File $Id: udf_unix.c,v 1.18 2022/12/03 15:25:36 reinoud Exp $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -293,7 +293,7 @@ if (0) {
 			TAILQ_INSERT_TAIL(&udf_node->vn_bufs, buf_entry, b_vnbufs);
 		} else {
 			buf = TAILQ_FIRST(&udf_node->vn_bufs);
-			while (buf->b_lblk < buf->b_lblk) {
+			while (buf->b_lblk < buf_entry->b_lblk) {
 				buf = TAILQ_NEXT(buf, b_vnbufs);
 			}
 			assert((buf->b_lblk != buf_entry->b_lblk) && (buf->b_vp == udf_node));
@@ -325,7 +325,7 @@ if (0) {
 	LIST_INSERT_HEAD(&udf_bufcache->udf_bufs[bucket], buf_entry, b_hash);
 
 	/* queue it in the lru chain */
-	if (udf_node->udf_filetype != UDF_ICB_FILETYPE_RANDOMACCESS) {
+	if ((udf_node->udf_filetype != UDF_ICB_FILETYPE_RANDOMACCESS) && (udf_node->udf_filetype != UDF_ICB_FILETYPE_REALTIME)) {
 		lru_chain = &udf_bufcache->lru_bufs_metadata;
 		udf_bufcache->lru_len_metadata++;
 	} else {
@@ -358,7 +358,7 @@ int udf_detach_buf_from_node(struct udf_node *udf_node, struct udf_buf *buf_entr
 	LIST_REMOVE(buf_entry, b_hash);
 
 	/* remove from lru lists */
-	if (udf_node->udf_filetype != UDF_ICB_FILETYPE_RANDOMACCESS) {
+	if ((udf_node->udf_filetype != UDF_ICB_FILETYPE_RANDOMACCESS) && (udf_node->udf_filetype != UDF_ICB_FILETYPE_REALTIME)) {
 		lru_chain = &udf_bufcache->lru_bufs_metadata;
 		TAILQ_REMOVE(lru_chain, buf_entry, b_lru);
 		udf_bufcache->lru_len_metadata--;
@@ -457,6 +457,7 @@ void *udf_purger(void *arg) {
 			/* writeout surplus of dirty buffers */
 			/* PURGE surplus bufs if possible */
 			if ((udf_bufcache->lru_len_data >= UDF_LRU_DATA_MIN) || udf_bufcache->flushall) {
+				DEBUG(printf("UDF read/write thread: purging dirty buffers\n"));
 				/* getting too many dirty data buffers */
 				TAILQ_INSERT_HEAD(&udf_bufcache->lru_bufs_data, marker, b_lru);
 				while ((buf_entry = TAILQ_NEXT(marker, b_lru))) {
@@ -477,7 +478,7 @@ DEBUG(printf("."); fflush(stdout));
 					}
 
 					/* if there are too many, drop least used */
-					if (udf_bufcache->lru_len_data > UDF_LRU_DATA_MIN) {
+					if (udf_bufcache->lru_len_data >= UDF_LRU_DATA_MIN) {
 						TAILQ_FOREACH(buf_entry, &udf_bufcache->lru_bufs_data, b_lru) {
 							/* process buf_entry */
 							if ((buf_entry != marker) && ((buf_entry->b_flags & B_DIRTY) == 0)) {
@@ -527,7 +528,7 @@ DEBUG(printf("+"); fflush(stdout));
 					}
 
 					/* if there are too many, drop least used */
-					if (udf_bufcache->lru_len_metadata > UDF_LRU_METADATA_MIN) {
+					if (udf_bufcache->lru_len_metadata >= UDF_LRU_METADATA_MIN) {
 						TAILQ_FOREACH(buf_entry, &udf_bufcache->lru_bufs_metadata, b_lru) {
 							/* process buf_entry */
 							if ((buf_entry != marker) && ((buf_entry->b_flags & B_DIRTY)) == 0) {
